==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/ProjectStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.NamespaceCondition;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ProjectStatusFluent<A extends io.fabric8.openshift.api.model.ProjectStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamespaceCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamespaceCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.NamespaceCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.NamespaceCondition> items);
  public java.util.List<io.fabric8.kubernetes.api.model.NamespaceCondition> getConditions();
  public io.fabric8.kubernetes.api.model.NamespaceCondition getCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NamespaceCondition getFirstCondition();
  public io.fabric8.kubernetes.api.model.NamespaceCondition getLastCondition();
  public io.fabric8.kubernetes.api.model.NamespaceCondition getMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamespaceCondition> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamespaceCondition> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.NamespaceCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public java.lang.String getPhase();
  public A withPhase(java.lang.String phase);
  public java.lang.Boolean hasPhase();
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0);
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ProjectStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.NamespaceCondition;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ProjectStatusFluent<A extends io.fabric8.openshift.api.model.ProjectStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamespaceCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamespaceCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.NamespaceCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.NamespaceCondition> items);
  public java.util.List<io.fabric8.kubernetes.api.model.NamespaceCondition> getConditions();
  public io.fabric8.kubernetes.api.model.NamespaceCondition getCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NamespaceCondition getFirstCondition();
  public io.fabric8.kubernetes.api.model.NamespaceCondition getLastCondition();
  public io.fabric8.kubernetes.api.model.NamespaceCondition getMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamespaceCondition> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamespaceCondition> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.NamespaceCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public java.lang.String getPhase();
  public A withPhase(java.lang.String phase);
  public java.lang.Boolean hasPhase();
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
